@@ -357,7 +357,7 @@ const VmeshSeparateFmParam * restrict const paraptr) /*+ Method parameters    +*
   if (hashnbr > vertnbr)                          /* Set bound on hash table */
     hashnbr = vertnbr;
   for (hashmax = 256; hashmax < hashnbr; hashmax <<= 1)
-    ; /* Get upper power of two */
+    continue; /* Get upper power of two */
 /* TODO */ hashmax *= 4;
   hashsiz = 4 * hashmax;
   hashmsk = hashsiz - 1;
