@@ -514,6 +514,13 @@ void Rmumps::set_keep(IntegerVector iv, IntegerVector ii) {
     param.keep[ii[i]-1]=iv[i];
   }
 }
+IntegerVector Rmumps::get_keep() {
+  // get a copy of control vector KEEP of length 500
+  IntegerVector res(500);
+  for (auto i=0; i < res.size(); i++)
+    res[i]=param.keep[i];
+  return res;
+}
 
 IntegerVector Rmumps::dim() {
   return IntegerVector::create(param.n, param.n);
@@ -763,7 +770,8 @@ RCPP_MODULE(mod_Rmumps){
   .method("set_cntl", &Rmumps::set_cntl, "Set CNTL parameter vector")
   .method("get_cntl", &Rmumps::get_cntl, "Get CNTL parameter vector")
   .method("get_infos", &Rmumps::get_infos, "Get a named list of information vectors")
-  .method("set_keep", &Rmumps::set_icntl, "Set KEEP parameter vector")
+  .method("set_keep", &Rmumps::set_keep, "Set KEEP parameter vector")
+  .method("get_keep", &Rmumps::get_keep, "Get a copy of KEEP parameter vector (length=500)")
   .method("dim", &Rmumps::dim, "Return a vector with matrix dimensions")
   .method("nrow", &Rmumps::nrow, "Return an integer with matrix row number")
   .method("ncol", &Rmumps::ncol, "Return an integer with matrix column number")
@@ -859,7 +867,7 @@ void Rmumps__set_mat_ptr(XPtr<Rmumps> pm, XPtr<double> pa) {
 //' In C++ code can be used as \code{rmumps::Rmumps__set_permutation(pm, permutation)}
 //'
 //' @param pm pointer of type XPtr<Rmumps>, object having sparse matrix permuted according to a chosen method.
-//' @param permutation integer one of predefined constants (cf. \code{\link{get_cnst}}). Setting a new permutation invalidates current symbolic and numeric matrix decompositions.
+//' @param permutation integer one of predefined constants (cf. \code{\link{RMUMPS_PERM}}). Setting a new permutation invalidates current symbolic and numeric matrix decompositions.
 //' @export
 // [[Rcpp::export]]
 void Rmumps__set_permutation(XPtr<Rmumps> pm, int permutation) {
